==> nextcloud-22.1.1.tgz: nextcloud/apps/circles/l10n/es_AR.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "Círculos",
    "The link between {circle} and {remote} has been shutdown remotely" : "El enlace entre {círculo} y {remoto} se ha cerrado de forma remota",
    "Personal" : "Personal",
    "Contact" : "Contacto",
    "Circle" : "Círculo",
    "Member" : "Miembro",
    "Moderator" : "Moderador",
    "Admin" : "Administrador",
    "Owner" : "Dueño",
    "%s shared »%s« with you." : "%s ha compartido »%s« con usted.",
    "Password to access »%s«" : "Contraseña para acceder  »%s«",
    "Click the button below to open it." : "Haga click en el botón de abajo para abrirlo.",
    "Open »%s«" : "Abrir »%s«",
    "A circle with that name exists" : "Un círculo con ese nombre ya existe",
    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "Usted no puede usar la Aplicación de Círculos hasta que su adminsitrador haya permitido al menos un tipo de círculo",
    "This member does not exist" : "Este miembro no existe",
    "This user is already a member of the circle" : "El usuario ya es un miembro del círculo",
    "You cannot join this circle" : "Usted no puede unirse a este cículo",
    "This member is not a moderator" : "Este miembro no es un moderador",
    "This member is the owner of the circle" : "Este miembro es el dueño del círculo",
    "You are already a member of this circle" : "Usted ya es un miembro de este círculo",
    "You have been blocked from this circle" : "Usted ha sido bloqueado de este círculo",
    "Accept" : "Aceptar",
    "Personal Circle" : "Círculo Personal",
    "You need a specify a type of circle" : "Usted necesita especificar un tipo de círculo",
    "This member is not the owner of the circle" : "Este miembro no es el dueño del círculo",
    "You cannot edit level in a personal circle" : "No puede editar el nivel en un círculo personal",
    "This user does not exist" : "Este usuario no existe",
    "Could not find share" : "No fue posible encontrar el elemento compartido",
    "No files in here" : "No hay archivos aqui",
    "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
    "Name" : "Nombre",
    "Size" : "Tamaño",
    "Modified" : "Modificado",
    "Personal circle" : "Círculo personal",
    "Public circle" : "Círculo público",
    "Public Circle" : "Círculo Público",
    "Secret" : "Secreto",
    "Public" : "Público",
    "Not a member" : "No es un miembro",
    "Unknown" : "Desconocido",
    "Invited" : "Invitado",
    "Requesting" : "Solicitando",
    "Blocked" : "Bloqueado",
    "Kicked" : "Expulsado",
    "Please confirm" : "Por favor confirmar",
    "Are you sure you want to delete this circle?" : "¿Está seguro que desea borrar este círculo?",
    "Mail Address" : "Dirección de Correo",
    "Kick this member" : "Sacar a este miembro",
    "Accept the request" : "Aceptar la solicitud",
    "Dismiss the request" : "Descartar la solicitud",
    "Cannot join this circle" : "Usted no se puede unir a este círculo",
    "no error message" : "no hay un mensaje de error",
    "You have requested to join this circle" : "Usted ha solicitado unirse a este círculo",
    "Cannot leave this circle" : "Usted no puede dejar este círculo",
    "Cannot delete this circle" : "No es posible borrar este círculo ",
    " {type} '{name}' created" : " {type} '{name}' ha sido creado",
    " {type} '{name}' could not be created" : " {type} '{name}' no pudo ser creado",
    "Issue while retrieving the details of this circle" : "Se presentó un tema al recuperar los detalles de este círculo",
    "Issue while retrieving the list of circles" : "Se presentó un tema al recuperar la lista de círculos",
    "A link to <b>{remote}</b> could not be initiated" : "No fue posible inicializar el link a <b>{remote}</b>",
    "A link to <b>{remote}</b> has been requested." : "Se ha solicitado un link a <b>{remote}</b>.",
    "the link to <b>{remote}</b> is now up and running." : "el link a <b>{remote}</b> ahora está disponible y funcionando.",
    "The name of your circle must contain at least 3 characters" : "El nombre de su círculo debe contener al menos 3 caracteres",
    "Federated circles are not allowed on this Nextcloud" : "No se permiten los círculos federados en este Nextcloud",
    "You cannot create this type of circle" : "No puede crear un círculo de este tipo",
    "You cannot display this type of circle" : "No puede desplegar un círculo de este tipo",
    "Federated link does not have a valid format" : "El link federada no tiene un formato válido",
    "Federated circles are not allowed on the remote Nextcloud" : "No se permiten los círculos federados en el Nextcloud remoto",
    "This link exists already" : "Este link ya existe",
    "The requested remote circle does not exist" : "El círculo remoto solicitado no existe",
    "Create a new circle" : "Crear un nuevo círculo",
    "Create a personal circle" : "Crear un círculo personal",
    "Create a public circle" : "Crear un círculo público",
    "A personal circle is a list of users known only to the owner." : "Un círculo personal es una lista de usuarios que es conocida solo por el dueño. ",
    "A public circle is an open group visible to anyone willing to join." : "Un círculo público es un grupo abierto, visible a todos aquellos que quieran unirse.",
    "All circles" : "Todos los círculos",
    "Search circles" : "Buscar círculos",
    "No filter" : "Sin filtro",
    "Circles you belong to" : "Círculos a los que pertenece",
    "Circles you own" : "Círculos que le pertenecen ",
    "No circle selected" : "No se ha selecccionado un círculo",
    "Settings" : "Ajustes",
    "Pending invitation to join this circle" : "Invitación pendiente para unirse a este círculo",
    "You have a pending request to join this circle" : "Usted tiene una solicitud pendiente para unirse a este círculo ",
    "Add a member" : "Agegar un miembro",
    "Join this circle" : "Unirse a este círculo",
    "Accept the invitation" : "Aceptar la invitación",
    "Decline the invitation" : "Declinar la invitación",
    "Leave this circle" : "Dejar este círculo",
    "Link to a circle" : "Enlazar a un círculo",
    "Username" : "Nombre de usuario",
    "Level" : "Nivel",
    "Status" : "Estatus",
    "Joined" : "Se ha unido",
    "Link" : "Link",
    "Description" : "Descripción",
    "Change password" : "Cambiar contraseña"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-22.2.8.tgz: nextcloud/apps/circles/l10n/es_AR.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "Círculos",
    "The link between {circle} and {remote} has been shutdown remotely" : "El enlace entre {círculo} y {remoto} se ha cerrado de forma remota",
    "Personal" : "Personal",
    "System" : "Sistema",
    "Visible" : "Visible",
    "Open" : "Abrir",
    "Hidden" : "Oculto",
    "Local" : "Local",
    "Root" : "Raíz",
    "Federated" : "Federado",
    "Contact" : "Contacto",
    "Circle" : "Círculo",
    "Member" : "Miembro",
    "Moderator" : "Moderador",
    "Admin" : "Administrador",
    "Owner" : "Dueño",
    "%s shared »%s« with you." : "%s ha compartido »%s« con usted.",
    "Password to access »%s«" : "Contraseña para acceder  »%s«",
    "Click the button below to open it." : "Haga click en el botón de abajo para abrirlo.",
    "Open »%s«" : "Abrir »%s«",
    "A circle with that name exists" : "Un círculo con ese nombre ya existe",
    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "Usted no puede usar la Aplicación de Círculos hasta que su adminsitrador haya permitido al menos un tipo de círculo",
    "This member does not exist" : "Este miembro no existe",
    "This user is already a member of the circle" : "El usuario ya es un miembro del círculo",
    "You cannot join this circle" : "Usted no puede unirse a este cículo",
    "This member is not a moderator" : "Este miembro no es un moderador",
    "This member is the owner of the circle" : "Este miembro es el dueño del círculo",
    "You are already a member of this circle" : "Usted ya es un miembro de este círculo",
    "You have been blocked from this circle" : "Usted ha sido bloqueado de este círculo",
    "Accept" : "Aceptar",
    "%s" : "%s",
    "Personal Circle" : "Círculo Personal",
    "You need a specify a type of circle" : "Usted necesita especificar un tipo de círculo",
    "This member is not the owner of the circle" : "Este miembro no es el dueño del círculo",
    "You cannot edit level in a personal circle" : "No puede editar el nivel en un círculo personal",
    "This user does not exist" : "Este usuario no existe",
    "Could not find share" : "No fue posible encontrar el elemento compartido",
    "No files in here" : "No hay archivos aqui",
    "No entries found in this folder" : "No se encontraron elementos en esta carpeta",
    "Name" : "Nombre",
    "Size" : "Tamaño",
    "Modified" : "Modificado"
},
"nplurals=2; plural=(n != 1);");
